@@ -65,12 +65,6 @@ namespace ada::unicode {
 bool to_ascii(std::optional<std::string>& out, std::string_view plain,
               size_t first_percent);
 
-/**
- * @private
- * @see https://www.unicode.org/reports/tr46/#ToUnicode
- */
-std::string to_unicode(std::string_view input);
-
 /**
  * @private
  * Checks if the input has tab or newline characters.
